@@ -119,6 +119,14 @@ def run():
     parser.add_argument(
         '--friends', type=int, help='When extracting a profile, how many friends to extract'
     )
+    parser.add_argument(
+        '-ppp',
+        '--posts-per-page',
+        dest='posts_per_page',
+        default=4,
+        type=int,
+        help="Number of posts to fetch per page",
+    )
 
     args = parser.parse_args()
 
@@ -131,7 +139,7 @@ def run():
     if args.profile:
         # Set a default filename, based on the account name with the appropriate extension
         if args.filename is None:
-            filename = str(args.account) + "_profile." + args.format
+            args.filename = str(args.account) + "_profile." + args.format
 
         if args.encoding is None:
             encoding = locale.getpreferredencoding()
@@ -139,7 +147,7 @@ def run():
         if args.filename == "-":
             output_file = sys.stdout
         else:
-            output_file = open(filename, 'w', newline='', encoding=encoding)
+            output_file = open(args.filename, 'w', newline='', encoding=encoding)
 
         profile = get_profile(args.account, friends=args.friends, cookies=args.cookies)
 
@@ -169,6 +177,7 @@ def run():
                 "reactors": args.reactors,
                 "comments": args.comments,
                 "allow_extra_requests": args.allow_extra_requests,
+                "posts_per_page": args.posts_per_page,
             },
             'youtube_dl': args.youtube_dl,
             'extra_info': args.extra_info,
