@@ -496,7 +496,9 @@ class PostExtractor:
             return None
 
     def extract_photo_link(self) -> PartialPost:
-        if not self.options.get("allow_extra_requests", True):
+        if not self.options.get("allow_extra_requests", True) or not self.options.get(
+            "HQ_images", True
+        ):
             return None
         images = []
         descriptions = []
@@ -715,7 +717,7 @@ class PostExtractor:
         reaction_lookup = self.get_jsmod("UFIReactionTypes")
         if reaction_lookup:
             reaction_lookup = reaction_lookup.get("reactions")
-            for k, v in self.live_data.get("reactioncountmap").items():
+            for k, v in self.live_data.get("reactioncountmap", {}).items():
                 if v["default"]:
                     name = reaction_lookup[k]["display_name"].lower()
                     reactions[name] = v["default"]
@@ -1100,10 +1102,15 @@ class PostExtractor:
         request_url_callback = self.options.get('comment_request_url_callback')
         more_url = None
         if more:
-            more_url = (
-                more.attrs.get("href")
-                + "&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
-            )
+            if self.options.get("response_url"):
+                more_url = utils.combine_url_params(
+                    self.options.get("response_url"), more.attrs.get("href")
+                )
+            else:
+                more_url = (
+                    more.attrs.get("href")
+                    + "&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
+                )
         if self.options.get("comment_start_url"):
             more_url = self.options.get("comment_start_url")
 
@@ -1139,10 +1146,15 @@ class PostExtractor:
                     yield result
             more = elem.find(more_selector, first=True)
             if more:
-                more_url = (
-                    more.attrs.get("href")
-                    + "&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
-                )
+                if self.options.get("response_url"):
+                    more_url = utils.combine_url_params(
+                        self.options.get("response_url"), more.attrs.get("href")
+                    )
+                else:
+                    more_url = (
+                        more.attrs.get("href")
+                        + "&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
+                    )
             else:
                 more_url = None
 
@@ -1174,7 +1186,7 @@ class PostExtractor:
                 links = response.html.find("#root .item>div>div>a:not(.touchable)")
                 for link in links:
                     people.append({"name": link.text, "link": link.attrs["href"]})
-            return {"with": people}
+            return {"with": people, "header": self.element.find("header h3", first=True).text}
 
     @property
     def data_ft(self) -> dict:
@@ -1200,7 +1212,12 @@ class PostExtractor:
         if self.options.get("allow_extra_requests", True) and self.post.get('post_id'):
             url = self.post.get('post_id')
             logger.debug(f"Fetching {url}")
-            response = self.request(url)
+            try:
+                response = self.request(url)
+            except exceptions.NotFound as e:
+                url = self.post.get('post_url').replace(FB_BASE_URL, FB_MOBILE_BASE_URL)
+                logger.debug(f"Fetching {url}")
+                response = self.request(url)
             self._full_post_html = response.html
             return self._full_post_html
         else:
