@@ -21,7 +21,7 @@ from .constants import (
 )
 from .extractors import extract_group_post, extract_post, extract_photo_post, PostExtractor
 from .fb_types import Post, Profile
-from .page_iterators import iter_group_pages, iter_pages, iter_photos
+from .page_iterators import iter_group_pages, iter_pages, iter_photos, iter_search_pages
 from . import exceptions
 
 
@@ -89,7 +89,8 @@ class FacebookScraper:
             logger.debug(f"Requesting page from: {url}")
             response = self.get(url)
             if response.url == "https://m.facebook.com/watch/?ref=watch_permalink":
-                if str(post_url).isdigit():
+                post_url = re.search("\d+", str(post_url)).group()
+                if post_url:
                     url = utils.urljoin(
                         FB_MOBILE_BASE_URL,
                         f"story.php?story_fbid={post_url}&id=1&m_entstream_source=timeline",
@@ -102,7 +103,10 @@ class FacebookScraper:
                 url = f"story.php?story_fbid={video_id}&id={video_id}&m_entstream_source=video_home&player_suborigin=entry_point&player_format=permalink"
                 logger.debug(f"Fetching {url}")
                 response = self.get(url)
+            options["response_url"] = response.url
             elem = response.html.find('[data-ft*="top_level_post_id"]', first=True)
+            if not elem:
+                elem = response.html.find('div.async_like', first=True)
             photo_post = False
             if response.html.find("div.msg", first=True):
                 photo_post = True
@@ -150,6 +154,11 @@ class FacebookScraper:
                     post.pop('source', None)
             yield post
 
+    def get_posts_by_search(self, word: str, **kwargs) -> Iterator[Post]:
+        kwargs["scraper"] = self
+        iter_pages_fn = partial(iter_search_pages, word=word, request_fn=self.get, **kwargs)
+        return self._generic_get_posts(extract_post, iter_pages_fn, **kwargs)
+
     def get_friends(self, account, **kwargs) -> Iterator[Profile]:
         friend_opt = kwargs.get("friends")
         limit = None
@@ -432,6 +441,66 @@ class FacebookScraper:
                     f'/{account}?v=following', limit=kwargs.get("following"), **kwargs
                 )
             )
+
+        # Likes
+        if result["id"] and kwargs.get("likes"):
+            likes_url = utils.urljoin(
+                FB_MOBILE_BASE_URL,
+                f'timeline/app_section/?section_token={result["id"]}:2409997254',
+            )
+            logger.debug(f"Requesting page from: {likes_url}")
+            response = self.get(likes_url)
+            result["likes_by_category"] = {}
+            for elem in response.html.find('header[data-sigil="profile-card-header"]'):
+                count, category = elem.text.split("\n")
+                count = utils.parse_int(count)
+                if category == "All Likes":
+                    result["likes_count"] = count
+                result["likes_by_category"][category] = count
+
+            all_likes_url = utils.urljoin(
+                FB_MOBILE_BASE_URL,
+                f'timeline/app_collection/?collection_token={result["id"]}:2409997254:96',
+            )
+            logger.debug(f"Requesting page from: {all_likes_url}")
+            response = self.get(all_likes_url)
+            result["likes"] = []
+            for elem in response.html.find("div._1a5p"):
+                result["likes"].append(
+                    {
+                        "name": elem.text,
+                        "link": elem.find("a", first=True).attrs.get("href"),
+                    }
+                )
+            more_url = re.search(r'href:"(/timeline/app_collection/more/[^"]+)"', response.text)
+            if more_url:
+                more_url = more_url.group(1)
+            while more_url:
+                logger.debug(f"Fetching {more_url}")
+                response = self.get(more_url)
+                prefix_length = len('for (;;);')
+                data = json.loads(response.text[prefix_length:])  # Strip 'for (;;);'
+                for action in data['payload']['actions']:
+                    if action['cmd'] == 'append' and action['html']:
+                        element = utils.make_html_element(
+                            action['html'],
+                            url=FB_MOBILE_BASE_URL,
+                        )
+                        for elem in element.find("div._1a5p"):
+                            result["likes"].append(
+                                {
+                                    "name": elem.text,
+                                    "link": elem.find("a", first=True).attrs.get("href"),
+                                }
+                            )
+                    elif action['cmd'] == 'script':
+                        more_url = re.search(
+                            r'("\\/timeline\\/app_collection\\/more\\/[^"]+")', action["code"]
+                        )
+                        if more_url:
+                            more_url = more_url.group(1)
+                            more_url = json.loads(more_url)
+
         return result
 
     def get_page_info(self, page, **kwargs) -> Profile:
@@ -443,7 +512,9 @@ class FacebookScraper:
             logger.debug(f"Requesting page from: {about_url}")
             resp = self.get(about_url)
             desc = resp.html.find("meta[name='description']", first=True)
-            result["about"] = resp.html.find('#pages_msite_body_contents', first=True).text
+            result["about"] = resp.html.find(
+                '#pages_msite_body_contents,div.aboutme', first=True
+            ).text
             cover_photo = resp.html.find("#msite-pages-header-contents i.coverPhoto", first=True)
             if cover_photo:
                 match = re.search(r"url\('(.+)'\)", cover_photo.attrs["style"])
@@ -459,13 +530,16 @@ class FacebookScraper:
             logger.debug(f"Requesting page from: {url}")
             resp = self.get(url)
             desc = resp.html.find("meta[name='description']", first=True)
-            elem = resp.html.find("script[type='application/ld+json']", first=True)
-            meta = json.loads(elem.text)
-            result.update(meta["author"])
-            result["type"] = result.pop("@type")
-            for interaction in meta.get("interactionStatistic", []):
-                if interaction["interactionType"] == "http://schema.org/FollowAction":
-                    result["followers"] = interaction["userInteractionCount"]
+            try:
+                elem = resp.html.find("script[type='application/ld+json']", first=True)
+                meta = json.loads(elem.text)
+                result.update(meta["author"])
+                result["type"] = result.pop("@type")
+                for interaction in meta.get("interactionStatistic", []):
+                    if interaction["interactionType"] == "http://schema.org/FollowAction":
+                        result["followers"] = interaction["userInteractionCount"]
+            except:
+                logger.error("No ld+json element")
             try:
                 result["about"] = resp.html.find(
                     '#pages_msite_body_contents>div>div:nth-child(2)', first=True
@@ -473,11 +547,26 @@ class FacebookScraper:
             except Exception as e:
                 logger.error(e)
                 result = self.get_profile(page)
-                result["followers"] = utils.convert_numeric_abbr(
-                    resp.html.find("span.unlinkedTextEntity", first=True).text.replace(
-                        " Followers", ""
+            for elem in resp.html.find("div[data-sigil*='profile-intro-card-log']"):
+                text = elem.text.split("\n")[0]
+                if " Followers" in text:
+                    result["followers"] = utils.convert_numeric_abbr(
+                        text.replace(" Followers", "")
                     )
-                )
+                if text.startswith("Price Range"):
+                    result["Price Range"] = text.split(" · ")[-1]
+                link = elem.find("a[href]", first=True)
+                if link:
+                    link = link.attrs["href"]
+                    if "active_ads" in link:
+                        result["active_ads_link"] = link
+                    if "maps.google.com" in link:
+                        result["map_link"] = parse_qs(urlparse(link).query).get("u")[0]
+                        result["address"] = text
+                    if link.startswith("tel:"):
+                        result["phone"] = link.replace("tel:", "")
+                    if link.startswith("mailto:"):
+                        result["email"] = link.replace("mailto:", "")
         except Exception as e:
             logger.error(e)
         if desc:
@@ -586,7 +675,9 @@ class FacebookScraper:
         if match:
             locale = match.groups(1)[0]
             if locale != "en_US":
-                warnings.warn(f"Locale detected as {locale} - for best results, set to en_US")
+                warnings.warn(
+                    f"Facebook language detected as {locale} - for best results, set to en_US"
+                )
             self.have_checked_locale = True
 
     def get(self, url, **kwargs):
